Wprime(object, session = NULL, quantity = c("expended", "balance"), w0, cp, version = c("2015", "2012"), meanRecoveryPower = FALSE, parallel = FALSE, cores = NULL, ...)trackeRdata object."expended" or W' "balance" be returned?"2015"
and "2012" for the versions presented in Skiba et al. (2015) and
Skiba et al. (2012), respectively. See Details.options("corese") (on Windows) or options("mc.cores") (elsewhere), or, if the relevant option is unspecified, to half the number of cores detected.trackeRWprime.
meanRecoveryPower to TRUE. Note that this employes information from the all observations
with a power output below critical power, not just those prior to the current time point.
data("runs", package = "trackeR")
wexp <- Wprime(runs, session = c(11,13), cp = 4, version = "2012")
plot(wexp)
Run the code above in your browser using DataLab