This smoother ensures a positive response (Poisson) that is a monotone decreasing function of x.
decreasingSmoother(x, y, k = 30, len = NULL, sp = NULL, fam = "poisson")The regressor passed on to the formula argument of scam.
The response passed on to the formula argument of scam.
Number of knots.
If NULL, the default, x is used for prediction. Otherwise,
prediction is done over the range of x with len equidistant points.
A vector of smoothing parameters passed on to scam.
A family object passed on to the family argument of scam.