getUnits.distrProfile: Get the units of the variables in an distrProfile object.
Description
Get the units of the variables in an distrProfile object.
Usage
# S3 method for distrProfile
getUnits(object, ...)
Arguments
object
An object of class distrProfile.