getUnits.trackeRWprime: Get the units of the variables in an trackeRWprime object.
Description
Get the units of the variables in an trackeRWprime object.
Usage
# S3 method for trackeRWprime
getUnits(object, ...)
Arguments
object
An object of class trackeRWprime.