get_units.trackeRfpca: Get the units of the variables in an trackeRfpca object
Description
Get the units of the variables in an trackeRfpca object
Usage
# S3 method for trackeRfpca
get_units(object, ...)
Arguments
- object
An object of class trackeRfpca.
- ...
Currently not used.