get_units.trackeRthresholds: Get the units of the variables in an trackeRthresholds object
Description
Get the units of the variables in an trackeRthresholds object
Usage
# S3 method for trackeRthresholds
get_units(object, ...)
Arguments
- object
An object of class trackeRthresholds.
- ...
Currently not used.