To ensure positivity of the smoothed concentration profiles, the concentration profiles are transformed to distribution profiles before smoothing. The smoothed distribution profiles are then transformed to concentration profiles.
# S3 method for conProfile
smoother(object, session = NULL, control = list(...),
...)An object of class conProfile as returned by concentrationProfile.
A numeric vector of the sessions to be selected and smoothed. Defaults to all sessions.
A list of parameters for controlling the smoothing process.
This is passed to smootherControl.distrProfile.
Arguments to be used to form the default control argument if it is not supplied directly.